pub trait SlicePattern {
type Item;
// Required method
fn as_slice(&self) -> &[Self::Item];
}🔬This is a nightly-only experimental API. (
slice_pattern #56345)Expand description
Patterns in slices - currently, only used by strip_prefix and strip_suffix. At a future
point, we hope to generalise core::str::Pattern (which at the time of writing is limited to
str) to slices, and then this trait will be replaced or abolished.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".